@@ -16,6 +16,7 @@ class CHMConan(ConanFile):
     options = {"verbose_cmake":[True,False], "build_tests":[True,False] }
 
     default_options = {"gperftools:heapprof":True,
+                       "*:shared":True,
                        "verbose_cmake":False,
                        "build_tests":True}
 
@@ -26,10 +27,15 @@ class CHMConan(ConanFile):
 
     def requirements(self):
         self.requires("cgal/[>=5.2]@CHM/stable")
-        self.requires("boost/[>=1.75.0]@CHM/stable")
-        self.requires("gdal/[>=3]@CHM/stable")
-        self.requires("proj/[>=7]@CHM/stable")
-        self.requires("metis/[>=5]@CHM/stable")
+        self.requires("boost/[>=1.75.0]")
+        self.requires("gdal/3.5.2")
+        self.requires("proj/9.0.1")
+        self.requires("metis/5.1.1")
+
+        self.requires("zlib/1.2.13", override=True)
+        self.requires("libtiff/4.4.0", override=True)
+        self.requires("sqlite3/3.39.3", override=True)
+        self.requires("libcurl/7.85.0", override=True)
 
     def _configure_cmake(self):
         cmake = CMake(self)
